==> owncloud-4.0.4.tgz: owncloud/apps/contacts/l10n/fa.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "خطا در (غیر) فعال سازی کتابچه نشانه ها",
"There was an error adding the contact." => "یک خطا در افزودن اطلاعات شخص مورد نظر",
"Cannot add empty property." => "نمیتوان یک  خاصیت خالی ایجاد کرد",
"At least one of the address fields has to be filled out." => "At least one of the address fields has to be filled out. ",
"Trying to add duplicate property: " => "امتحان کردن برای وارد کردن مشخصات تکراری",
"Error adding contact property." => "خطا درهنگام افزودن ویژگی",
"No ID provided" => "هیچ شناسه ای ارائه نشده",
"Error setting checksum." => "خطا در تنظیم checksum",
"No categories selected for deletion." => "هیچ گروهی برای حذف شدن در نظر گرفته نشده",
"No address books found." => "هیچ کتابچه نشانی پیدا نشد",
"No contacts found." => "هیچ شخصی پیدا نشد",
"Missing ID" => "نشانی گم شده",
"Error parsing VCard for ID: \"" => "خطا در تجزیه کارت ویزا برای شناسه:",
"Cannot add addressbook with an empty name." => "نمیتوانید یک نام خالی را به کتابچه نشانی ها افزود",
"Error adding addressbook." => "خطا درهنگام افزودن کتابچه نشانی ها",
"Error activating addressbook." => "خطا درهنگام فعال سازیکتابچه نشانی ها",
"No contact ID was submitted." => "هیچ اطلاعاتی راجع به شناسه ارسال نشده",
"Error reading contact photo." => "خطا در خواندن اطلاعات تصویر",
"Error saving temporary file." => "خطا در ذخیره پرونده موقت",
"The loading photo is not valid." => "بارگزاری تصویر امکان پذیر نیست",
"id is not set." => "شناسه تعیین نشده",
"Information about vCard is incorrect. Please reload the page." => "اطلاعات درمورد vCard شما اشتباه است لطفا صفحه را دوباره بار گذاری کنید",
"Error deleting contact property." => "خطا در هنگام پاک کرد ویژگی",
"Contact ID is missing." => "اطلاعات شناسه گم شده",
"Missing contact id." => "شما اطلاعات شناسه را فراموش کرده اید",
"No photo path was submitted." => "هیچ نشانی از تصویرارسال نشده",
"File doesn't exist:" => "پرونده وجود ندارد",
"Error loading image." => "خطا در بارگزاری تصویر",
"element name is not set." => "نام اصلی تنظیم نشده است",
"checksum is not set." => "checksum تنظیم شده نیست",
"Information about vCard is incorrect. Please reload the page: " => "اطلاعات کارت ویزا شما غلط است لطفا صفحه را دوباره بارگزاری کنید",
"Something went FUBAR. " => "چند چیز به FUBAR رفتند",
"Error updating contact property." => "خطا در هنگام بروزرسانی  اطلاعات شخص مورد نظر",
"Cannot update addressbook with an empty name." => "نمی توانید کتابچه نشانی ها را با یک نام خالی بروزرسانی کنید",
"Error updating addressbook." => "خطا در هنگام بروزرسانی کتابچه نشانی ها",
"Error uploading contacts to storage." => "خطا در هنگام بارگذاری و ذخیره سازی",
"There is no error, the file uploaded with success" => "هیچ خطایی نیست بارگذاری پرونده موفقیت آمیز بود",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "حجم آپلود از طریق Php.ini تعیین می شود",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
"The uploaded file was only partially uploaded" => "پرونده بارگذاری شده فقط تاحدودی بارگذاری شده",
"No file was uploaded" => "هیچ پروندهای بارگذاری نشده",
"Missing a temporary folder" => "یک پوشه موقت گم شده",
"Contacts" => "اشخاص",
"Drop a VCF file to import contacts." => "یک پرونده VCF را به اینجا بکشید تا اشخاص افزوده شوند",
"Addressbook not found." => "کتابچه نشانی ها یافت نشد",
"This is not your addressbook." => "این کتابچه ی نشانه های شما نیست",
"Contact could not be found." => "اتصال ویا تماسی یافت نشد",
"Address" => "نشانی",
"Telephone" => "تلفن",
"Email" => "نشانی پست الکترنیک",
"Organization" => "نهاد(ارگان)",
"Work" => "کار",
"Home" => "خانه",
"Mobile" => "موبایل",
"Text" => "متن",
"Voice" => "صدا",
"Message" => "پیغام",
"Fax" => "دورنگار:",
"Video" => "رسانه تصویری",
"Pager" => "صفحه",
"Internet" => "اینترنت",
"{name}'s Birthday" => "روز تولد {name} است",
"Contact" => "اشخاص",
"Add Contact" => "افزودن اطلاعات شخص مورد نظر",
"Addressbooks" => "کتابچه ی نشانی ها",
"Configure Address Books" => "پیکر بندی کتابچه نشانی ها",
"New Address Book" => "کتابچه نشانه های جدید",
"Import from VCF" => "وارد شده از VCF",
"CardDav Link" => "CardDav Link",
"Download" => "بارگیری",
"Edit" => "ویرایش",
"Delete" => "پاک کردن",
"Download contact" => "دانلود مشخصات اشخاص",
"Delete contact" => "پاک کردن  اطلاعات شخص مورد نظر",
"Drop photo to upload" => "تصویر را به اینجا بکشید تا بار گذازی شود",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Format custom, Short name, Full name, Reverse or Reverse with comma",
"Edit name details" => "ویرایش نام جزئیات",
"Nickname" => "نام مستعار",
"Enter nickname" => "یک نام مستعار وارد کنید",
"Birthday" => "روزتولد",
"dd-mm-yyyy" => "dd-mm-yyyy",
"Groups" => "گروه ها",
"Separate groups with commas" => "جدا کردن گروه ها به وسیله درنگ نما",
"Edit groups" => "ویرایش گروه ها",
"Preferred" => "مقدم",
"Please specify a valid email address." => "لطفا یک پست الکترونیکی معتبر وارد کنید",
"Enter email address" => "یک  پست الکترونیکی وارد کنید",
"Mail to address" => "به نشانی  ارسال شد",
"Delete email address" => "پاک کردن نشانی پست الکترونیکی",
"Enter phone number" => "شماره تلفن راوارد کنید",
"Delete phone number" => "پاک کردن شماره تلفن",
"View on map" => "دیدن روی نقشه",
"Edit address details" => "ویرایش جزئیات نشانی ها",
"Add notes here." => "اینجا یادداشت ها را بیافزایید",
"Add field" => "اضافه کردن فیلد",
"Profile picture" => "تصویر پروفایل",
"Phone" => "شماره تلفن",
"Note" => "یادداشت",
"Delete current photo" => "پاک کردن تصویر کنونی",
"Edit current photo" => "ویرایش تصویر کنونی",
"Upload new photo" => "بار گذاری یک تصویر جدید",
"Select photo from ownCloud" => "انتخاب یک تصویر از ابر های شما",
"Edit address" => "ویرایش نشانی",
"Type" => "نوع",
"PO Box" => "صندوق پستی",
"Extended" => "تمدید شده",
"Street" => "خیابان",
"City" => "شهر",
"Region" => "ناحیه",
"Zipcode" => "کد پستی",
"Country" => "کشور",
"Edit categories" => "ویرایش گروه",
"Add" => "افزودن",
"Addressbook" => "کتابچه ی نشانی ها",
"Hon. prefixes" => "پیشوند های محترمانه",
"Miss" => "خانم",
"Ms" => "خانم",
"Mr" => "آقا",
"Sir" => "آقا",
"Mrs" => "خانم",
"Dr" => "دکتر",
"Given name" => "نام معلوم",
"Additional names" => "نام های دیگر",
"Family name" => "نام خانوادگی",
"Hon. suffixes" => "پسوند های محترم",
"J.D." => "J.D.",
"M.D." => "M.D.",
"D.O." => "D.O.",
"D.C." => "D.C.",
"Ph.D." => "دکتری",
"Esq." => "Esq.",
"Jr." => "Jr.",
"Sn." => "Sn.",
"New Addressbook" => "کتابچه نشانی جدید",
"Edit Addressbook" => "ویرایش کتابچه نشانی",
"Displayname" => "نام برای نمایش",
"Active" => "فعال",
"Save" => "ذخیره سازی",
"Submit" => "ارسال",
"Cancel" => "انصراف",
"Import a contacts file" => "وارد کردن پرونده حاوی اطلاعات",
"Please choose the addressbook" => "لطفا یک کتابچه نشانی انتخاب کنید",
"create a new addressbook" => "یک کتابچه نشانی بسازید",
"Name of new addressbook" => "نام کتابچه نشانی جدید",
"Import" => "وارد کردن",
"Importing contacts" => "وارد کردن اشخاص",
"Select address book to import to:" => "یک کتابچه نشانی انتخاب کنید تا وارد شود",
"Select from HD" => "انتخاب از دیسک سخت",
"You have no contacts in your addressbook." => "شماهیچ شخصی در  کتابچه نشانی خود ندارید",
"Add contact" => "افزودن اطلاعات شخص مورد نظر",
"Configure addressbooks" => "پیکربندی کتابچه ی نشانی ها",
"CardDAV syncing addresses" => "CardDAV syncing addresses ",
"more info" => "اطلاعات بیشتر",
"Primary address (Kontact et al)" => "نشانی اولیه",
"iOS/OS X" => "iOS/OS X "
);

==> owncloud-4.5.7.tgz: owncloud/apps/contacts/l10n/fa.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "خطا در (غیر) فعال سازی کتابچه نشانه ها",
"id is not set." => "شناسه تعیین نشده",
"Cannot update addressbook with an empty name." => "نمی توانید کتابچه نشانی ها را با یک نام خالی بروزرسانی کنید",
"No ID provided" => "هیچ شناسه ای ارائه نشده",
"Error setting checksum." => "خطا در تنظیم checksum",
"No categories selected for deletion." => "هیچ گروهی برای حذف شدن در نظر گرفته نشده",
"No address books found." => "هیچ کتابچه نشانی پیدا نشد",
"No contacts found." => "هیچ شخصی پیدا نشد",
"element name is not set." => "نام اصلی تنظیم نشده است",
"Cannot add empty property." => "نمیتوان یک  خاصیت خالی ایجاد کرد",
"At least one of the address fields has to be filled out." => "At least one of the address fields has to be filled out. ",
"Trying to add duplicate property: " => "امتحان کردن برای وارد کردن مشخصات تکراری",
"Information about vCard is incorrect. Please reload the page." => "اطلاعات درمورد vCard شما اشتباه است لطفا صفحه را دوباره بار گذاری کنید",
"Missing ID" => "نشانی گم شده",
"Error parsing VCard for ID: \"" => "خطا در تجزیه کارت ویزا برای شناسه:",
"checksum is not set." => "checksum تنظیم شده نیست",
"Information about vCard is incorrect. Please reload the page: " => "اطلاعات کارت ویزا شما غلط است لطفا صفحه را دوباره بارگزاری کنید",
"Something went FUBAR. " => "چند چیز به FUBAR رفتند",
"No contact ID was submitted." => "هیچ اطلاعاتی راجع به شناسه ارسال نشده",
"Error reading contact photo." => "خطا در خواندن اطلاعات تصویر",
"Error saving temporary file." => "خطا در ذخیره پرونده موقت",
"The loading photo is not valid." => "بارگزاری تصویر امکان پذیر نیست",
"Contact ID is missing." => "اطلاعات شناسه گم شده",
"No photo path was submitted." => "هیچ نشانی از تصویرارسال نشده",
"File doesn't exist:" => "پرونده وجود ندارد",
"Error loading image." => "خطا در بارگزاری تصویر",
"Error getting contact object." => "خطا در گرفتن اطلاعات شخص",
"Error getting PHOTO property." => "خطا در دربافت تصویر ویژگی شخصی",
"Error saving contact." => "خطا در ذخیره سازی اطلاعات",
"Error resizing image" => "خطا در تغییر دادن اندازه تصویر",
"Error cropping image" => "خطا در برداشت تصویر",
"Error creating temporary image" => "خطا در ساخت تصویر  temporary",
"Error finding image: " => "خطا در پیدا کردن تصویر:",
"Error uploading contacts to storage." => "خطا در هنگام بارگذاری و ذخیره سازی",
"There is no error, the file uploaded with success" => "هیچ خطایی نیست بارگذاری پرونده موفقیت آمیز بود",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "حجم آپلود از طریق Php.ini تعیین می شود",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
"The uploaded file was only partially uploaded" => "پرونده بارگذاری شده فقط تاحدودی بارگذاری شده",
"No file was uploaded" => "هیچ پروندهای بارگذاری نشده",
"Missing a temporary folder" => "یک پوشه موقت گم شده",
"Couldn't save temporary image: " => "قابلیت ذخیره تصویر  موقت وجود ندارد:",
"Couldn't load temporary image: " => "قابلیت بارگذاری تصویر  موقت وجود ندارد:",
"No file was uploaded. Unknown error" => "هیچ فایلی آپلود نشد.خطای ناشناس",
"Contacts" => "اشخاص",
"Sorry, this functionality has not been implemented yet" => "با عرض پوزش،این قابلیت هنوز اجرا نشده است",
"Not implemented" => "انجام نشد",
"Couldn't get a valid address." => "Couldn't get a valid address.",
"Error" => "خطا",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Format custom, Short name, Full name, Reverse or Reverse with comma",
"Select type" => "نوع را انتخاب کنید",
"This property has to be non-empty." => "این ویژگی باید به صورت غیر تهی عمل کند",
"Couldn't serialize elements." => "قابلیت مرتب سازی عناصر وجود ندارد",
"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "پاک کردن ویژگی بدون استدلال انجام شده.لطفا این مورد را گزارش دهید:bugs.owncloud.org",
"Edit name" => "نام تغییر",
"No files selected for upload." => "هیچ فایلی برای آپلود انتخاب نشده است",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "حجم فایل بسیار بیشتر از حجم تنظیم شده در تنظیمات سرور است",
"Result: " => "نتیجه:",
" imported, " => "وارد شد،",
" failed." => "ناموفق",
"Download" => "بارگیری",
"Edit" => "ویرایش",
"Delete" => "پاک کردن",
"Cancel" => "انصراف",
"This is not your addressbook." => "این کتابچه ی نشانه های شما نیست",
"Contact could not be found." => "اتصال ویا تماسی یافت نشد",
"Work" => "کار",
"Home" => "خانه",
"Mobile" => "موبایل",
"Text" => "متن",
"Voice" => "صدا",
"Message" => "پیغام",
"Fax" => "دورنگار:",
"Video" => "رسانه تصویری",
"Pager" => "صفحه",
"Internet" => "اینترنت",
"Birthday" => "روزتولد",
"{name}'s Birthday" => "روز تولد {name} است",
"Contact" => "اشخاص",
"Add Contact" => "افزودن اطلاعات شخص مورد نظر",
"Import" => "وارد کردن",
"Close" => "بستن",
"Drop photo to upload" => "تصویر را به اینجا بکشید تا بار گذازی شود",
"Delete current photo" => "پاک کردن تصویر کنونی",
"Edit current photo" => "ویرایش تصویر کنونی",
"Upload new photo" => "بار گذاری یک تصویر جدید",
"Select photo from ownCloud" => "انتخاب یک تصویر از ابر های شما",
"Edit name details" => "ویرایش نام جزئیات",
"Organization" => "نهاد(ارگان)",
"Nickname" => "نام مستعار",
"Enter nickname" => "یک نام مستعار وارد کنید",
"dd-mm-yyyy" => "dd-mm-yyyy",
"Groups" => "گروه ها",
"Separate groups with commas" => "جدا کردن گروه ها به وسیله درنگ نما",
"Edit groups" => "ویرایش گروه ها",
"Preferred" => "مقدم",
"Please specify a valid email address." => "لطفا یک پست الکترونیکی معتبر وارد کنید",
"Enter email address" => "یک  پست الکترونیکی وارد کنید",
"Mail to address" => "به نشانی  ارسال شد",
"Delete email address" => "پاک کردن نشانی پست الکترونیکی",
"Enter phone number" => "شماره تلفن راوارد کنید",
"Delete phone number" => "پاک کردن شماره تلفن",
"View on map" => "دیدن روی نقشه",
"Edit address details" => "ویرایش جزئیات نشانی ها",
"Add notes here." => "اینجا یادداشت ها را بیافزایید",
"Add field" => "اضافه کردن فیلد",
"Phone" => "شماره تلفن",
"Email" => "نشانی پست الکترنیک",
"Address" => "نشانی",
"Note" => "یادداشت",
"Download contact" => "دانلود مشخصات اشخاص",
"Delete contact" => "پاک کردن  اطلاعات شخص مورد نظر",
"The temporary image has been removed from cache." => "تصویر موقت از کش پاک شد.",
"Edit address" => "ویرایش نشانی",
"Type" => "نوع",
"PO Box" => "صندوق پستی",
"Extended" => "تمدید شده",
"City" => "شهر",
"Region" => "ناحیه",
"Zipcode" => "کد پستی",
"Country" => "کشور",
"Addressbook" => "کتابچه ی نشانی ها",
"Hon. prefixes" => "پیشوند های محترمانه",
"Miss" => "خانم",
"Ms" => "خانم",
"Mr" => "آقا",
"Sir" => "آقا",
"Mrs" => "خانم",
"Dr" => "دکتر",
"Given name" => "نام معلوم",
"Additional names" => "نام های دیگر",
"Family name" => "نام خانوادگی",
"Hon. suffixes" => "پسوند های محترم",
"J.D." => "J.D.",
"M.D." => "M.D.",
"D.O." => "D.O.",
"D.C." => "D.C.",
"Ph.D." => "دکتری",
"Esq." => "Esq.",
"Jr." => "Jr.",
"Sn." => "Sn.",
"Import a contacts file" => "وارد کردن پرونده حاوی اطلاعات",
"Please choose the addressbook" => "لطفا یک کتابچه نشانی انتخاب کنید",
"create a new addressbook" => "یک کتابچه نشانی بسازید",
"Name of new addressbook" => "نام کتابچه نشانی جدید",
"Importing contacts" => "وارد کردن اشخاص",
"Add contact" => "افزودن اطلاعات شخص مورد نظر",
"CardDAV syncing addresses" => "CardDAV syncing addresses ",
"more info" => "اطلاعات بیشتر",
"Primary address (Kontact et al)" => "نشانی اولیه",
"iOS/OS X" => "iOS/OS X ",
"Addressbooks" => "کتابچه ی نشانی ها",
"New Address Book" => "کتابچه نشانه های جدید",
"Save" => "ذخیره سازی"
);
